@@ -16,14 +16,15 @@ package Debian::Control::FromCPAN;
 use strict;
 use warnings;
 
-our $VERSION = '0.94';
+our $VERSION = '0.95';
 
 use Carp qw(croak);
 
 use base 'Debian::Control';
 
 use CPAN ();
-use DhMakePerl::Utils qw( is_core_module find_cpan_module nice_perl_ver split_version_relation apt_cache );
+use DhMakePerl::Utils qw( is_core_module find_cpan_module nice_perl_ver
+  split_version_relation apt_cache is_core_perl_package );
 use File::Spec qw( catfile );
 use Module::Depends ();
 
@@ -321,6 +322,11 @@ sub find_debs_for_modules {
             $dep = Debian::Dependency->new( 'perl', $ver );
         }
         elsif ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
+            # core packages should be included above
+            # it is normal to have them here, in case the version
+            # requirement can't be satisfied by the current perl
+            @pkgs = grep { !is_core_perl_package($_) } @pkgs;
+
             $dep = Debian::Dependency->new(
                   ( @pkgs > 1 )
                 ? [ map { { pkg => $_, ver => $version } } @pkgs ]
@@ -403,11 +409,7 @@ sub find_debs_for_modules {
                 my $alt_dep;
 
                 if ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
-                    @pkgs = grep {
-                                ( $_ !~ /^perl-modules(?:-[\d.]+)?$/ )
-                            and ( $_ ne 'perl-base' )
-                            and ( $_ ne 'perl' )
-                    } @pkgs;
+                    @pkgs = grep { !is_core_perl_package($_) } @pkgs;
 
                     $alt_dep = Debian::Dependency->new(
                           ( @pkgs > 1 )
@@ -511,10 +513,11 @@ sub prune_simple_perl_dep {
     croak "No alternative dependencies can be given"
         if $dep->alternatives;
 
-    return $dep unless $dep->pkg =~ /^(?:perl|perl-base|perl-modules(?:-[\d.]+)?)$/;
+    return $dep unless is_core_perl_package( $dep->pkg );
 
     # perl-modules is replaced with perl
-    $dep->pkg('perl') if $dep->pkg =~ /^perl-modules(?:-[\d.]+)?$/;
+    $dep->pkg('perl')
+      if $dep->pkg =~ /^(?:perl-modules(?:-[\d.]+)?|libperl[\d.]+)$/;
 
     my $unversioned = (
         not $dep->ver
@@ -574,7 +577,8 @@ sub prune_perl_dep {
 
 =item prune_perl_deps
 
-Remove redundant (build-)dependencies on perl, perl-modules and perl-base.
+Remove redundant (build-)dependencies on perl, libperl, perl-modules and
+perl-base.
 
 =cut
 
