@@ -3,7 +3,7 @@ package DhMakePerl::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.94';
+our $VERSION = '0.95';
 
 =head1 NAME
 
@@ -22,6 +22,7 @@ our @EXPORT_OK = qw(
     find_core_perl_dependency
     apt_cache
     find_cpan_module find_cpan_distribution
+    is_core_perl_package
     is_core_module
     nice_perl_ver
     split_version_relation
@@ -115,6 +116,28 @@ sub find_cpan_distribution {
         "/\\/$name-[^\\/]+\\.(tar|zip)/" );
 }
 
+=item is_core_perl_package I<package>
+
+Returns true value if the given package is a core Perl package, i.e. one of
+C<perl>, C<perl-base>, C<perl-modules-X.Y> and C<libperlX.Y>.
+
+Having this in a central routine makes it easier to add/remove packages in the
+list.
+=cut
+
+sub is_core_perl_package {
+    my ($pkg) = @_;
+
+    $pkg =~ s/:\w+$//;  # strip architecture
+
+    return 1
+      if $pkg eq 'perl-base'
+      or $pkg eq 'perl'
+      or $pkg =~ /^perl-modules(?:-[\d.]+)?$/
+      or $pkg =~ /^libperl[\d.]+$/;
+    return 0;
+}
+
 =item is_core_module I<module>, I<version>
 
 Returns the version of the C<perl> package containing the given I<module> (at
